@@ -38,7 +38,7 @@ def uploadFolder(dataFolder,platoUrl):
     a=str(curr_file.parent.joinpath(dataFolder).resolve())
     print(a)
     
-    if "uploadSchema.json" in dataFolder:
+    if "uploadSchema.json" in os.listdir(dataFolder):
         
         with open(os.path.join(dataFolder,"uploadSchema.json").replace("\\","/"),"r",encoding="utf8") as uploadSchemaFile:
             uploadSchemaJson=json.load(uploadSchemaFile)
